import ttkbootstrap as tb
import ttkbootstrap.constants
from tkinter import messagebox, filedialog
import requests
import os


def create_shop_frame(parent, switch_func, api_url, token):
    frame = tb.Frame(parent)

    selected_file_path = [None]

    def select_file():
        file_path = filedialog.askopenfilename(title="Select Shop Image")
        if file_path:
            selected_file_path[0] = file_path
            file_label.config(text=os.path.basename(file_path))
        else:
            selected_file_path[0] = None
            file_label.config(text="No file selected")

    def create_shop():
        name = entry_name.get()
        description = entry_description.get()

        if not name:
            messagebox.showwarning("Input Error", "Shop name is required!")
            return

        url = f"{api_url}/shops"
        data = {"name": name, "description": description}
        files = {}

        if selected_file_path[0]:
            try:
                files["file"] = open(selected_file_path[0], "rb")
            except Exception as e:
                messagebox.showerror("File Error", f"Unable to open file: {str(e)}")
                return

        if not token:
            messagebox.showerror(
                "Token Error", "Access token not found. Please log in."
            )
            return

        headers = {"Authorization": f"Bearer {token}"}
        print(f"Access Token in create_shop: {token}")  # Debugging line

        try:
            response = requests.post(url, data=data, files=files, headers=headers)
            if "file" in files:
                files["file"].close()

            response_data = response.json()
            if response.status_code == 200:
                messagebox.showinfo(
                    "Shop Created", f"Shop '{name}' created successfully!"
                )
            else:
                messagebox.showerror(
                    "Error", response_data.get("detail", "An error occurred")
                )
        except Exception as e:
            messagebox.showerror("Request Error", str(e))

    tb.Label(frame, text="Create Shop", font=("Helvetica", 18, "bold")).pack(pady=10)

    tb.Label(frame, text="Shop Name:").pack(pady=5)
    entry_name = tb.Entry(frame, bootstyle="info")
    entry_name.pack(pady=5)

    tb.Label(frame, text="Description:").pack(pady=5)
    entry_description = tb.Entry(frame, bootstyle="info")
    entry_description.pack(pady=5)

    tb.Button(
        frame, text="Select Image", bootstyle="primary", command=select_file
    ).pack(pady=5)
    file_label = tb.Label(frame, text="No file selected")
    file_label.pack(pady=5)

    tb.Button(frame, text="Create Shop", bootstyle="success", command=create_shop).pack(
        pady=15
    )

    tb.Button(
        frame,
        text="Back",
        bootstyle="link",
        command=lambda: switch_func("login"),
    ).pack(pady=5)

    return frame
